#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pandoc-plot
version:              1.9.1
visibility:           public
id:                   pandoc-plot-1.9.1-39dpJIHd4G14lIfpsBKzu3
key:                  pandoc-plot-1.9.1-39dpJIHd4G14lIfpsBKzu3
license:              GPL-2.0-or-later
copyright:            (c) 2019-present Laurent P. René de Cotret
maintainer:           Laurent P. René de Cotret
author:               Laurent P. René de Cotret
homepage:             https://github.com/LaurentRDC/pandoc-plot#readme
synopsis:
    A Pandoc filter to include figures generated from code blocks using your plotting toolkit of choice.

description:
    A Pandoc filter to include figures generated from code blocks.
    Keep the document and code in the same location. Output is
    captured and included as a figure.

category:             Text
abi:                  c7982d4da76a6abc50e07ca1a17dbc2c
exposed:              True
exposed-modules:
    Text.Pandoc.Filter.Plot Text.Pandoc.Filter.Plot.Internal

hidden-modules:
    Paths_pandoc_plot Text.Pandoc.Filter.Plot.Clean
    Text.Pandoc.Filter.Plot.Configuration Text.Pandoc.Filter.Plot.Parse
    Text.Pandoc.Filter.Plot.Scripting
    Text.Pandoc.Filter.Plot.Scripting.Template
    Text.Pandoc.Filter.Plot.Renderers
    Text.Pandoc.Filter.Plot.Renderers.Prelude
    Text.Pandoc.Filter.Plot.Renderers.Matplotlib
    Text.Pandoc.Filter.Plot.Renderers.PlotlyPython
    Text.Pandoc.Filter.Plot.Renderers.PlotlyR
    Text.Pandoc.Filter.Plot.Renderers.Matlab
    Text.Pandoc.Filter.Plot.Renderers.Mathematica
    Text.Pandoc.Filter.Plot.Renderers.Octave
    Text.Pandoc.Filter.Plot.Renderers.GGPlot2
    Text.Pandoc.Filter.Plot.Renderers.GNUPlot
    Text.Pandoc.Filter.Plot.Renderers.Graphviz
    Text.Pandoc.Filter.Plot.Renderers.Bokeh
    Text.Pandoc.Filter.Plot.Renderers.Plotsjl
    Text.Pandoc.Filter.Plot.Renderers.PlantUML
    Text.Pandoc.Filter.Plot.Renderers.SageMath
    Text.Pandoc.Filter.Plot.Renderers.D2
    Text.Pandoc.Filter.Plot.Renderers.Asymptote
    Text.Pandoc.Filter.Plot.Renderers.Mermaid
    Text.Pandoc.Filter.Plot.Monad Text.Pandoc.Filter.Plot.Monad.Logging
    Text.Pandoc.Filter.Plot.Monad.Types Text.Pandoc.Filter.Plot.Embed

import-dirs:          /usr/lib/ghc-9.6.6/site-local/pandoc-plot-1.9.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pandoc-plot-1.9.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pandoc-plot-1.9.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/pandoc-plot
hs-libraries:         HSpandoc-plot-1.9.1-39dpJIHd4G14lIfpsBKzu3
depends:
    aeson-2.2.2.0-1j2UQRt1mV1Loqrh8KvmRL base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz directory-1.3.8.5
    filepath-1.4.300.1 hashable-1.4.7.0-H7NkROSKCrjFQZGpvHIgO1
    lifted-async-0.11.0-kFxVZ6qzjyBywACnHDOE4
    lifted-base-0.2.3.12-Lg2Cbhgxj9N169cZWUBSF1 mtl-2.3.1
    pandoc-3.6-FosHnOrBTvjBs02zzCXwgV
    pandoc-types-1.23.1-G7QY9CPJSQFhNGtD8Sqsj
    shakespeare-2.1.7.1-HAihHFmY68PKZa96E6qCo6
    tagsoup-0.14.8-FmrdBUkUK9IFv8QmYpfcP3 template-haskell-2.20.0.0
    text-2.0.2 typed-process-0.2.13.0-6u6wFfn6DMG9NJZ9BxYSzU
    yaml-0.11.11.2-4nq91yAXiWkLGvTAafAlR5

haddock-interfaces:   /usr/share/doc/pandoc-plot/html/pandoc-plot.haddock
haddock-html:         /usr/share/doc/pandoc-plot/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

